{% load i18n %}
<a {% if url %}href="{{ url }}"{% else %}disabled{% endif %} data-toggle="tooltip" title="{% trans "Refresh data collection schedule" %}" role="button" class="btn btn-sm btn-default"><i class="fas fa-arrows-rotate fa-1x fa-fw" aria-hidden="true"></i></a>
